@@ -24,7 +24,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include "sieveeditor_debug.h"
-#include "helper_p.h"
 
 /** static helper functions **/
 static QString authenticationModeString(MailTransport::Transport::EnumAuthenticationType::type mode)
@@ -60,7 +59,7 @@ static void addAuthenticationItem(QComboBox *authCombo, MailTransport::Transport
 
 static MailTransport::Transport::EnumAuthenticationType::type getCurrentAuthMode(QComboBox *authCombo)
 {
-    MailTransport::Transport::EnumAuthenticationType::type authtype = (MailTransport::Transport::EnumAuthenticationType::type) authCombo->itemData(authCombo->currentIndex()).toInt();
+    MailTransport::Transport::EnumAuthenticationType::type authtype = (MailTransport::Transport::EnumAuthenticationType::type)authCombo->itemData(authCombo->currentIndex()).toInt();
     //qCDebug(SIEVEEDITOR_LOG) << "current auth mode: " << authenticationModeString( authtype );
     return authtype;
 }
@@ -74,15 +73,15 @@ static void setCurrentAuthMode(QComboBox *authCombo, MailTransport::Transport::E
     }
     //qCDebug(SIEVEEDITOR_LOG) << "found corresponding index: " << index << "with data" << authenticationModeString( (MailTransport::Transport::EnumAuthenticationType::type) authCombo->itemData( index ).toInt() );
     authCombo->setCurrentIndex(index);
-    MailTransport::Transport::EnumAuthenticationType::type t = (MailTransport::Transport::EnumAuthenticationType::type) authCombo->itemData(authCombo->currentIndex()).toInt();
+    MailTransport::Transport::EnumAuthenticationType::type t = (MailTransport::Transport::EnumAuthenticationType::type)authCombo->itemData(authCombo->currentIndex()).toInt();
     //qCDebug(SIEVEEDITOR_LOG) << "selected auth mode:" << authenticationModeString( t );
     Q_ASSERT(t == authtype);
 }
 
-ServerSieveSettings::ServerSieveSettings(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::ServerSieveSettings),
-    mServerTest(nullptr)
+ServerSieveSettings::ServerSieveSettings(QWidget *parent)
+    : QWidget(parent)
+    , ui(new Ui::ServerSieveSettings)
+    , mServerTest(nullptr)
 {
     ui->setupUi(this);
     ui->serversievelabel->setMinimumSize(ui->serversievelabel->sizeHint());
@@ -162,12 +161,12 @@ void ServerSieveSettings::setUserName(const QString &name)
 
 QString ServerSieveSettings::password() const
 {
-    return ui->password->text();
+    return ui->password->password();
 }
 
 void ServerSieveSettings::setPassword(const QString &pass)
 {
-    ui->password->setText(pass);
+    ui->password->setPassword(pass);
 }
 
 QString ServerSieveSettings::imapServerName() const
@@ -202,12 +201,12 @@ void ServerSieveSettings::setImapUserName(const QString &name)
 
 QString ServerSieveSettings::imapPassword() const
 {
-    return ui->imapPassword->text();
+    return ui->imapPassword->password();
 }
 
 void ServerSieveSettings::setImapPassword(const QString &pass)
 {
-    ui->imapPassword->setText(pass);
+    ui->imapPassword->setPassword(pass);
 }
 
 void ServerSieveSettings::setAuthenticationType(KSieveUi::SieveImapAccountSettings::AuthenticationMode type)
@@ -273,6 +272,11 @@ SieveEditorUtil::SieveServerConfig ServerSieveSettings::serverSieveConfig() cons
 
 void ServerSieveSettings::slotTest()
 {
+    const QString server = imapServerName().isEmpty() ? serverName() : imapServerName();
+    if (server.isEmpty()) {
+        KMessageBox::error(this, i18n("Server is not defined"), i18n("Check Server"));
+        return;
+    }
     //qCDebug(SIEVEEDITOR_LOG) << ui->imapServer->text();
     ui->testButton->setEnabled(false);
     ui->safeImap->setEnabled(false);
@@ -287,7 +291,6 @@ void ServerSieveSettings::slotTest()
     qApp->setOverrideCursor(Qt::BusyCursor);
 #endif
 
-    const QString server = imapServerName().isEmpty() ? serverName() : imapServerName();
     const int portValue = ui->imapPort->value();
     qCDebug(SIEVEEDITOR_LOG) << "server: " << server << "port: " << portValue;
 
@@ -376,7 +379,7 @@ void ServerSieveSettings::slotSafetyChanged()
     QVector<int> protocols;
 
     switch (ui->safeImapGroup->checkedId()) {
-    case KSieveUi::SieveImapAccountSettings::Unencrypted :
+    case KSieveUi::SieveImapAccountSettings::Unencrypted:
         qCDebug(SIEVEEDITOR_LOG) << "safeImapGroup: unencrypted";
         protocols = mServerTest->normalProtocols();
         break;
@@ -395,12 +398,12 @@ void ServerSieveSettings::slotSafetyChanged()
     ui->imapAuthenticationCombo->clear();
     addAuthenticationItem(ui->imapAuthenticationCombo, MailTransport::Transport::EnumAuthenticationType::CLEAR);
     for (int prot : qAsConst(protocols)) {
-        addAuthenticationItem(ui->imapAuthenticationCombo, (MailTransport::Transport::EnumAuthenticationType::type) prot);
+        addAuthenticationItem(ui->imapAuthenticationCombo, (MailTransport::Transport::EnumAuthenticationType::type)prot);
     }
     if (protocols.isEmpty()) {
         qCDebug(SIEVEEDITOR_LOG) << "no authmodes found";
     } else {
-        setCurrentAuthMode(ui->imapAuthenticationCombo, (MailTransport::Transport::EnumAuthenticationType::type) protocols.constFirst());
+        setCurrentAuthMode(ui->imapAuthenticationCombo, (MailTransport::Transport::EnumAuthenticationType::type)protocols.constFirst());
     }
     mServerTest->deleteLater();
     mServerTest = nullptr;
